@@ -1,38 +1,43 @@
 #!/usr/bin/env python
 
-import pygtk
+import os
+import requests
 
-pygtk.require('2.0')
-import gtk
+if(os.environ.get('TRAVIS')!='true'):
+    import pygtk
 
-import webbrowser
+    pygtk.require('2.0')
+    import gtk
+
+    import webbrowser
+
+    try:
+        import appindicator
+    except ImportError:
+        import appindicator_replacement as appindicator
+
+    from appindicator_replacement import get_icon_filename
+    
 import json
 import argparse
 from os.path import expanduser
 import signal
 
-try:
-    import appindicator
-except ImportError:
-    import appindicator_replacement as appindicator
-
-from appindicator_replacement import get_icon_filename
-
 ##This is to get --version to work
 try:
     import pkg_resources
 
     __version = pkg_resources.require("hackertray")[0].version
-except ImportError:
+except:
     __version = "Can't read version number."
 
 from hackernews import HackerNews
-
+from chrome import Chrome
 
 class HackerNewsApp:
     HN_URL_PREFIX = "https://news.ycombinator.com/item?id="
 
-    def __init__(self, comments):
+    def __init__(self, args):
         #Load the database
         home = expanduser("~")
         with open(home + '/.hackertray.json', 'a+') as content_file:
@@ -52,7 +57,7 @@ class HackerNewsApp:
         self.menu = gtk.Menu()
 
         #The default state is false, and it toggles when you click on it
-        self.commentState = comments
+        self.commentState = args.comments
 
         # create items for the menu - refresh, quit and a separator
         menuSeparator = gtk.SeparatorMenuItem()
@@ -61,7 +66,7 @@ class HackerNewsApp:
 
         btnComments = gtk.CheckMenuItem("Show Comments")
         btnComments.show()
-        btnComments.set_active(comments)
+        btnComments.set_active(args.comments)
         btnComments.connect("activate", self.toggleComments)
         self.menu.append(btnComments)
 
@@ -73,7 +78,7 @@ class HackerNewsApp:
         btnRefresh = gtk.MenuItem("Refresh")
         btnRefresh.show()
         #the last parameter is for not running the timer
-        btnRefresh.connect("activate", self.refresh, True)
+        btnRefresh.connect("activate", self.refresh, True, args.chrome)
         self.menu.append(btnRefresh)
 
         btnQuit = gtk.MenuItem("Quit")
@@ -84,7 +89,7 @@ class HackerNewsApp:
         self.menu.show()
 
         self.ind.set_menu(self.menu)
-        self.refresh()
+        self.refresh(chrome_data_directory=args.chrome)
 
     def toggleComments(self, widget):
         """Whether comments page is opened or not"""
@@ -135,7 +140,9 @@ class HackerNewsApp:
         i = gtk.CheckMenuItem(
             "(" + str(item['points']).zfill(3) + "/" + str(item['comments_count']).zfill(3) + ")    " + item['title'])
 
-        i.set_active(item['id'] in self.db)
+        visited = item['history'] or item['id'] in self.db
+
+        i.set_active(visited)
         i.url = item['url']
         i.signal_id = i.connect('activate', self.open)
         i.hn_id = item['id']
@@ -143,29 +150,43 @@ class HackerNewsApp:
         self.menu.prepend(i)
         i.show()
 
-    def refresh(self, widget=None, no_timer=False):
+    def refresh(self, widget=None, no_timer=False, chrome_data_directory=None):
+
         """Refreshes the menu """
-        data = reversed(HackerNews.getHomePage()[0:20])
+        try:
+            data = list(reversed(HackerNews.getHomePage()[0:20]))
+            if(chrome_data_directory):
+                urls = [item['url'] for item in data]
+                searchResults = Chrome.search(urls, chrome_data_directory)
 
-        #Remove all the current stories
-        for i in self.menu.get_children():
-            if hasattr(i, 'url'):
-                self.menu.remove(i)
+            #Remove all the current stories
+            for i in self.menu.get_children():
+                if hasattr(i, 'url'):
+                    self.menu.remove(i)
 
-        #Add back all the refreshed news
-        for i in data:
-            self.addItem(i)
-
-        #Call every 5 minutes
-        if not no_timer:
-            gtk.timeout_add(10 * 60 * 1000, self.refresh)
+            #Add back all the refreshed news
+            for index, item in enumerate(data):
+                if(chrome_data_directory):
+                    item['history'] = searchResults[index]
+                else:
+                    item['history'] = False
+                self.addItem(item)
+        # Catch network errors
+        except requests.exceptions.RequestException as e:
+            print "There was an error in fetching news items"
+        finally:
+            # Call every 10 minutes
+            if not no_timer:
+                gtk.timeout_add(10 * 30 * 1000, self.refresh, widget, no_timer, chrome_data_directory)
 
+        
 
 def main():
     parser = argparse.ArgumentParser(description='Hacker News in your System Tray')
     parser.add_argument('-v','--version', action='version', version=__version)
     parser.add_argument('-c','--comments', dest='comments',action='store_true', help="Load the HN comments link for the article as well")
+    parser.add_argument('--chrome', dest='chrome', help="Specify a Google Chrome Profile directory to use for matching chrome history")
     parser.set_defaults(comments=False)
     args = parser.parse_args()
-    indicator = HackerNewsApp(args.comments)
+    indicator = HackerNewsApp(args)
     indicator.run()
